@@ -1,4 +1,5 @@
 import discord
+import re
 
 
 __all__ = (
@@ -10,14 +11,28 @@ __all__ = (
 )
 
 
+def _partial_emoji_converter(argument: str):
+    if len(argument) == 1:
+        return discord.PartialEmoji(name=argument)
+    
+    match = re.match(r'<(a?):([a-zA-Z0-9\_]+):([0-9]+)>$', argument)
+
+    if match:
+        emoji_animated = bool(match.group(1))
+        emoji_name = match.group(2)
+        emoji_id = int(match.group(3))
+
+        return discord.PartialEmoji(name=emoji_name, animated=emoji_animated, id=emoji_id)
+
+    raise discord.InvalidArgument(f"Failed to convert {argument} to PartialEmoji")
+
+
 def auto_rows(*buttons, max_in_row: int=5):
     """
     Distributes buttons across multiple rows
     and returns the list of rows.
-
     Example
     -------
-
     ::
 
         rows = auto_rows(
@@ -25,21 +40,22 @@ def auto_rows(*buttons, max_in_row: int=5):
             Button(label="Green", custom_id="green", style=3),
             max_in_row=1
         )
-
+        await ctx.send("Buttons", components=rows)
+    
     Parameters
     ----------
     buttons : List[:class:`Button`]
         a list of buttons to distribute
     max_in_row : :class:`int`
-        limit of buttons in a single row
+        limit of buttons in a single row. Must be between 1 and 5.
     
     Returns
     -------
     List[:class:`ActionRow`]
         the list of rows with buttons
     """
-    if not (0 < max_in_row < 5):
-        raise discord.InvalidArgument("max_in_row should be from 0 to 5")
+    if not (1 <= max_in_row <= 5):
+        raise discord.InvalidArgument("max_in_row parameter should be between 1 and 5.")
     rows = []
     for i in range(0, len(buttons), max_in_row):
         rows.append(ActionRow(*buttons[i:i + max_in_row]))
@@ -90,7 +106,7 @@ class Button(Component):
         Style of the button
     label : :class:`str`
         Button text
-    emoji : :class:`discord.PartialEmoji`
+    emoji : :class:`str` | :class:`discord.PartialEmoji`
         Button emoji
     custom_id : :class:`str`
         You should set it by yourself, it's not a snowflake.
@@ -113,6 +129,9 @@ class Button(Component):
             raise discord.InvalidArgument("you can't specify both url and custom_id")
         elif style == ButtonStyle.link:
             raise discord.InvalidArgument("style 'link' expects url to be specified")
+        
+        if isinstance(emoji, str):
+            emoji = _partial_emoji_converter(emoji)
 
         super().__init__(2)
         self.style = style
@@ -177,7 +196,7 @@ class ActionRow(Component):
             raise discord.InvalidArgument("components must be a list of Component")
         
         super().__init__(1)
-        self.components = components
+        self.components = list(components)
     
     def __repr__(self):
         return "<ActionRow buttons={0.components!r}>".format(self)
